==> haskell-strict-list-0.1.7.6-125.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-JIfe1DsCbLp7n7ZCmVBiDO
key:                  strict-list-0.1.7.6-JIfe1DsCbLp7n7ZCmVBiDO
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  398e09000f5f02ea0a87c7edaabf9239
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-JIfe1DsCbLp7n7ZCmVBiDO
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-list-0.1.7.6-126-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-33IElGv1emkKg5CjRd99pG
key:                  strict-list-0.1.7.6-33IElGv1emkKg5CjRd99pG
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  ee563179f8ca2fa313e354a445d346bb
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-33IElGv1emkKg5CjRd99pG
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
